## Description
<!-- Describe your changes in detail -->

## Type of change
<!-- Please delete options that are not relevant -->

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Code refactoring
- [ ] Test improvement
- [ ] Chore (dependencies, CI, etc.)

## Related Issue
<!-- If this PR fixes an issue, please link it here -->
Fixes #(issue number)

## Changes Made
<!-- List the main changes made in this PR -->

- 
- 
- 

## Testing
<!-- Describe the tests you ran to verify your changes -->

- [ ] All existing tests pass (`mise run test`)
- [ ] Added new tests for new functionality
- [ ] All CI checks pass (`mise run ci`)

## Checklist
<!-- Please check all that apply -->

- [ ] My code follows the code style of this project (`mise run format` and `mise run lint`)
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] I have updated the CHANGELOG.md under `[Unreleased]` section
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published

## Screenshots (if applicable)
<!-- Add screenshots to help explain your changes -->

## Additional Notes
<!-- Add any additional notes or context about the PR here -->
